import {AdRecord} from "../records/ad.record";
import {pool} from "../utils/db";
import {AdEntity} from "../types";

const defaultObj = {
    id: 'ghi',
    name: 'Name of test...',
    description: "Testing...",
    url: 'https://dominikdrozd.it',
    price: 20,
    lat: 21,
    lon: 90,
};

afterAll(async () => {
    await pool.end();
})

test('AdRecord returns data from database for one entry.', async () => {

    const ad = await AdRecord.getOne('abc');

    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('Testowa');
});

test('AdRecord.getOne returns null from database for unexisting entry.', async () =>
{
    const ad = await AdRecord.getOne('xyz');

    expect(ad).toBeNull();
});

test('AdRecord.getAll returns array of all entries from database.', async () =>{
    const ads = await AdRecord.getAll();

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});

test('AdRecord.findAll returns smaller amount of data.', async () =>{
    const ads = await AdRecord.findAll('');

    expect((ads[0] as AdEntity).price).toBeUndefined();
    expect((ads[0] as AdEntity).description).toBeUndefined();
});

test('AdRecord.findAll returns array of found entries.', async () =>{
    const ads = await AdRecord.findAll('');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});

test('AdRecord.findAll returns array of found entries when searching for "a".', async () =>{
    const ads = await AdRecord.findAll('a');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});

test('AdRecord.findAll returns empty array when searching for something that does not exists.', async () =>{
    const ads = await AdRecord.findAll('-------------------');

    expect(ads).toEqual([]);
});

test('insert data to database', async () => {
    const ad = new AdRecord(defaultObj);

    const id = await ad.insert();

    expect(id).toBe(defaultObj.id);
})
